import { Separator } from "./Separator";
import { AuthorData } from "./table";
import { cn } from "./util/cn";
import React, { useState } from 'react';

interface CommentDataBase {
    id: number;
    author: AuthorData;
    text: string;
    timestamp: string;
    showDelete?: boolean;
}
export interface SubCommentData extends CommentDataBase {
    parentId?: number;
}
export interface CommentData extends CommentDataBase {
    subComments?: SubCommentData[]; // Optional sub-comments
}

export function CommentListContainer({
    children,
}: {
    children: React.ReactNode;
}) {
    return <ul className="list-none pl-0 m-0 text-[13px]">{children}</ul>
}
export function CommentItem({ comment }: { comment: CommentData }) {
    const renderSubComments = () => {
        if (comment.subComments && comment.subComments.length > 0) {
            return (
                <CommentReplySection comments={comment.subComments} />
            );
        }
        return null; // No sub-comments to render
    }
    return <>
        <li className="bg-transparent text-[13px]">
            <div className="border-t relative border-custom-gray-light px-[3px] pt-[9px] pb-[7px] flex"
            >
                <div style={{
                    width: '132px', marginRight: '33px', marginTop: '3px',
                    lineHeight: '13px'
                }}>
                    <span className="relative text-[13px] cursor-pointer inline">
                        <span
                            className="font-normal algin-top text-[12px] text-[#777777]"
                        >
                            <em
                                className="overflow-hidden text-ellipsis not-italic
                            align-tops pr-px inline-block text-nowrap max-w-[110px]"
                            > {comment.author.type === 'nickname' ? comment.author.nickname : 'ㅇㅇ'} </em>
                        </span>
                        {comment.author.type === 'nickname' && (
                            <a className="text-custom-gray-dark inline">
                                <img
                                    className="inline-block align-middle cursor-pointer"
                                    src="/fix_nik.gif" alt="icon"
                                />
                            </a>
                        )}
                    </span>
                </div>
                <div style={{
                    width: '820px', cursor: 'pointer'
                }}
                    className="flex-1"
                >
                    <p style={{
                        lineHeight: '20px', cursor: 'pointer',
                        wordBreak: 'break-all',
                        overflowX: 'hidden', overflowY: 'hidden', width: '820px'
                    }}
                        className="overflow-hidden break-all cursor-pointer"
                    > {comment.text} </p>
                </div>
                <div className="flex items-center justify-between">
                    <span className="text-custom-gray-medium align-middle mt-px text-[12px] float-left">
                        {comment.timestamp}
                    </span>
                    {comment.showDelete && (
                        <div className="flex items-center justify-end ml-[6px] relative">
                            <button className="
                        bg-sp-img bg-[-268px_-200px] w-[13px] h-[13px]
                        align-top font-apple-dotum
                        " />
                        </div>
                    )}
                </div>
            </div>
        </li>
        {renderSubComments()}
    </>
}

function CommentReplyItem({ comment }: { comment: SubCommentData }) {
    // Function to handle potential HTML in author name
    const renderAuthor = () => {
        const authorMaxWidth = comment.author.type === 'IP' ? '84px' : '107px'; // Default to 107px if not specified
        return (
            <em
                className="inline-block text-ellipsis overflow-hidden whitespace-nowrap align-top not-italic text-custom-gray-dark"
                style={{ maxWidth: authorMaxWidth }} // Apply dynamic max-width
            >
                {comment.author.type === 'nickname' ? comment.author.nickname : 'ㅇㅇ'}
            </em>
        );
    };

    return (
        <li className="bg-transparent pt-[9px] pr-3 pb-[7px] pl-3 border-t border-solid border-gray-300 first:border-t-0">
            <div className="bg-transparent relative flow-root"> {/* Use flow-root to contain floats */}
                {/* Author Info */}
                <div className="bg-transparent float-left w-[133px] mr-[23px] mt-[3px] leading-[13px]">
                    <span className="bg-transparent relative text-[13px] cursor-pointer">
                        <span className="bg-transparent text-xs text-gray-700 align-top">
                            {renderAuthor()}
                            {comment.author.type === "IP" && ( // Conditionally render IP if it exists
                                <span className="bg-transparent font-tahoma text-[11px] text-custom-gray-medium inline-block align-[1px] ml-1">
                                    ({comment.author.ip})
                                </span>
                            )}
                            {comment.author.type === "nickname" && (
                                <a
                                    className="text-custom-gray-dark inline ml-1"
                                > <img
                                        className="inline-block align-middle cursor-pointer"
                                        src={
                                            comment.author.userType === "manager" ? "/fix_managernik.gif" :
                                                comment.author.userType === "submanager" ? "/fix_sub_managernik.gif" :
                                                    "/fix_nik.gif"} alt="icon"
                                    />
                                </a>
                            )}
                        </span>
                    </span>
                </div>

                {/* Timestamp and Actions (float right first in source order for correct float behavior) */}
                <div className="bg-transparent float-right">
                    <span className="bg-transparent float-left text-xs text-custom-gray-medium align-top mt-[1px] mr-2">
                        {comment.timestamp}
                    </span>
                    {comment.showDelete && ( // Conditionally render delete button
                        <div className="bg-transparent float-right relative top-[3px] right-0">
                            {/* Using top-[3px] might need adjustment based on exact alignment needs */}
                            <button
                                title="삭제" // Add title for accessibility
                                className="bg-transparent cursor-pointer align-top text-[0px] font-apple-dotum text-custom-gray-medium bg-sp-img bg-[-268px_-200px] leading-none w-[13px] h-[13px]"
                            >
                                삭제 {/* Text hidden by text-[0px] but good for screen readers */}
                            </button>
                        </div>
                    )}
                </div>

                {/* Comment Text */}
                {/* Note: Original has width 820px container and 774px text. Simulating this might require careful flex/grid or removing float here */}
                {/* Simplified approach: Let text flow, adjust margins if needed */}
                <div className="bg-transparent overflow-hidden cursor-default"> {/* Use overflow-hidden to contain the text after floats */}
                    <p className="leading-5 cursor-default break-words pl-0">
                        {/* Removed float, width, relative, padding-left: 16px from original P. Adjust if layout breaks */}
                        {/* Original P had pl-16px (pl-4). Let's add it back relative to the start of this div */}
                        <span className="inline-block pl-4">{comment.text}</span> {/* Wrapped text in span to apply padding */}
                    </p>
                </div>

            </div>
        </li>
    );
}

export function CommentReplySection({ comments }: { comments: SubCommentData[] }) {
    return (
        <div className="bg-transparent overflow-hidden h-full text-[13px]"> {/* Assuming full height needed */}
            <div className="bg-gray-50 mb-3 ml-[30px] border border-solid border-gray-300">
                <ul className="bg-transparent list-none">
                    {comments.map((comment) => (
                        <CommentReplyItem key={comment.id} comment={comment} />
                    ))}
                </ul>
            </div>
        </div>
    );
}

// Define the props the component will accept
interface CommentPaginationProps {
    currentPage: number;
    maxPage: number;
    onPageChange?: (page: number) => void; // Optional callback for page changes
    onViewContent?: () => void; // Optional click handler for "본문 보기"
    onCloseComments?: () => void; // Optional click handler for "댓글닫기"
    onRefresh?: () => void; // Optional click handler for "새로고침"
}

export const CommentPagination: React.FC<CommentPaginationProps> = ({
    currentPage,
    maxPage,
    onViewContent,
    onCloseComments,
    onRefresh,
}) => {
    const pageNumbers = Array.from({ length: maxPage }, (_, i) => i + 1); // Generate page numbers

    return (
        <div className="relative mt-[18px] text-center leading-[20px] border-t border-t-custom-gray-light text-[0px] h-[69px] font-apple-dotum">
            {/* Page Number Section */}
            {/* pt/pb values approximate vertical centering within the 69px height */}
            {/* text-center on parent handles horizontal centering */}
            <div className="pt-[23px] pb-[28px]">
                {pageNumbers.map((page) => (
                    <em className={cn("inline-block ml-[9px] text-[14px] font-bold not-italic",
                        currentPage === page && "underline text-custom-red-text"
                    )}>
                        {page}
                    </em>
                ))}
                {/* Add other page numbers logic here if needed */}
            </div>

            {/* Buttons Section */}
            <div className="absolute right-0 top-0 mt-[23px] text-[0px] flex items-center">
                <a
                    href="#view-content" // Use a more appropriate href or make it a button if it triggers an action
                    onClick={(e) => {
                        if (onViewContent) {
                            e.preventDefault(); // Prevent default anchor behavior if it's an action
                            onViewContent();
                        }
                        // Allow default behavior if onViewContent is not provided and href is meaningful
                    }}
                    className="text-custom-gray-dark align-middle leading-[15px] inline-block text-[13px] font-bold font-apple no-underline hover:underline cursor-pointer"
                >
                    본문 보기
                </a>
                <Separator className='mx-2.5' />
                <button
                    type="button"
                    onClick={onCloseComments}
                    className="bg-transparent cursor-pointer align-middle text-[13px] font-apple text-custom-gray-dark font-bold" // Added margin consistency
                >
                    <span className="inline-block text-[13px] font-bold font-apple text-custom-gray-dark"> {/* Removed redundant ml-9, parent button has it */}
                        댓글닫기
                    </span>
                    {/* The @utility bg-sp-img needs to be correctly processed by your CSS build tool */}
                    <em className="bg-sp-img bg-[-84px_-52px] inline-block w-[9px] h-[5px] ml-[4px] align-[2px]">
                        {/* Empty em for background image icon */}
                    </em>
                </button>
                <Separator className='mx-2.5' />
                <button
                    type="button"
                    onClick={onRefresh}
                    className="bg-transparent cursor-pointer align-middle text-[13px] font-apple text-custom-gray-dark font-bold" // Added margin consistency
                >
                    새로고침
                </button>
            </div>
        </div>
    );
};

export function CommentInput() {
    const [isNicknameTooltipVisible, setIsNicknameTooltipVisible] = useState(true); // Show initially based on HTML
    const [isDcConInfoVisible, setIsDcConInfoVisible] = useState(false); // Hidden initially

    // TODO: Implement state for input values
    // const [nickname, setNickname] = useState('');
    // const [password, setPassword] = useState('');
    // const [comment, setComment] = useState('');

    const toggleDcConInfo = () => setIsDcConInfoVisible(!isDcConInfoVisible);
    const hideNicknameTooltip = () => setIsNicknameTooltipVisible(false);

    return (
        <div className="bg-custom-gray-very-light p-3 border-t-2 border-b-2 border-solid border-custom-blue-hover font-apple-dotum text-xs">
            {/* Use flexbox for layout instead of floats */}
            <div className="flex justify-between">

                {/* Left Column: Nickname/Password */}
                <div className="flex flex-col space-y-[5px]">
                    {/* Nickname Input */}
                    <div className="relative w-[140px] h-[30px] bg-white border border-custom-border-input">
                        <label htmlFor="nickname" className="sr-only">닉네임</label>

                        {/* Nickname Tooltip */}
                        {isNicknameTooltipVisible && (
                            <div className="absolute right-auto top-[-57px] left-[-14px] bg-custom-green-light rounded-[5px] shadow-tooltip z-[99]">
                                <div className="relative py-[7px] pr-[28px] pl-[11px]">
                                    <p className="text-white text-xs leading-4 whitespace-nowrap tracking-normal">
                                        ㅇㅇ는 갤러리에서 권장하는 비회원 전용<br />
                                        갤닉네임입니다. (삭제 시 닉네임 등록 가능)
                                    </p>
                                    <button
                                        type="button"
                                        onClick={hideNicknameTooltip}
                                        className="absolute top-[10px] right-[10px] w-3 h-3 bg-sp-img bg-[-267px_-818px] cursor-pointer align-[-2px]"
                                        aria-label="닫기"
                                    >
                                        <em className="sr-only">닫기</em>
                                    </button>
                                </div>
                                <div
                                    style={{
                                        borderWidth: "9px 6px 0px 6px",
                                        borderColor: "#98ca33 transparent",
                                        top: "auto",
                                        bottom: "-8px",
                                        left: "33px",
                                        right: "auto",
                                        marginTop: "-6px",
                                        borderStyle: "solid",
                                        position: "absolute",
                                    }}
                                />
                            </div>
                        )}

                        {/* Actual Input */}
                        <input
                            type="text"
                            id="nickname"
                            // value={nickname}
                            // onChange={(e) => setNickname(e.target.value)}
                            className="align-top text-xs font-apple w-[126px] h-[28px] leading-tight-29 py-[1px] px-[7px] text-custom-blue-dark border-none outline-none"
                            placeholder="닉네임" // Use placeholder attribute
                        />
                        {/* Delete Button (Implement functionality if needed) */}
                        <button type="button" className="absolute right-[7px] top-[7px] w-4 h-4 cursor-pointer align-middle">
                            {/* Add icon here if needed, original HTML has no visible icon */}
                            <span className="sr-only">삭제</span>
                        </button>

                        {/* Hidden 'Use Gallery Nickname' Button */}
                        <button type="button" className="hidden absolute right-0 top-0 h-[30px] pr-2 text-xs font-apple-dotum underline text-custom-blue-dark cursor-pointer align-middle">
                            갤닉네임 사용
                        </button>
                    </div>

                    {/* Password Input */}
                    <div className="relative w-[140px] h-[30px] bg-white border border-custom-border-input">
                        <label htmlFor="password" className="sr-only">비밀번호</label>
                        <input
                            type="password"
                            id="password"
                            // value={password}
                            // onChange={(e) => setPassword(e.target.value)}
                            className="align-top text-xs font-apple w-[126px] h-[28px] leading-tight-29 py-[1px] px-[7px] border-none outline-none"
                            placeholder="비밀번호" // Use placeholder attribute
                        />
                    </div>
                </div>

                {/* Right Column: Textarea and Buttons */}
                {/* Calculate width: 100% - left column width - gap. Or use flex-grow */}
                <div className="flex-grow ml-3"> {/* Adjust margin as needed */}
                    {/* Textarea */}
                    <div className="relative">
                        <label
                            htmlFor="comment"
                            className="absolute left-0 top-0 p-[13px] text-xs text-custom-gray-medium leading-[18px] pointer-events-none" // Prevent label from blocking textarea
                        >
                            타인의 권리를 침해하거나 명예를 훼손하는 댓글은 운영원칙 및 관련 법률에 제재를 받을 수 있습니다.<br />
                            Shift+Enter 키를 동시에 누르면 줄바꿈이 됩니다.
                        </label>
                        <textarea
                            id="comment"
                            // value={comment}
                            // onChange={(e) => setComment(e.target.value)}
                            className="align-middle text-[13px] font-apple w-full h-[78px] p-[13px] border border-custom-border-input bg-white text-custom-gray-dark leading-[18px] resize-none outline-none focus:bg-white" // Ensure bg is white on focus to hide label
                        // Add logic to hide placeholder label when typing starts if needed
                        />
                    </div>

                    {/* Buttons Row */}
                    <div className="mt-2 flex justify-between items-center">
                        {/* Left Buttons (DCCon) */}
                        <div className="relative flex items-center">
                            <button
                                type="button"
                                className="bg-white border border-custom-blue-dark text-custom-blue-dark font-bold text-xs w-[82px] h-[31px] px-[2px] leading-tight-29 rounded-2 flex items-center justify-center cursor-pointer ml-[3px]"
                            >
                                <em className="bg-sp-img inline-block w-6 h-[19px] mr-[5px] ml-[2px] bg-[-229px_0px] align-[-5px]"></em>
                                디시콘
                            </button>
                            <button
                                type="button"
                                onClick={toggleDcConInfo}
                                className="ml-1 mt-px cursor-pointer"
                                aria-label="디시콘이란"
                                aria-expanded={isDcConInfoVisible}
                            >
                                <em className="bg-sp-img inline-block w-[17px] h-[16px] bg-[-220px_-29px]"></em>
                            </button>

                            {/* DCCon/NFT Info Popup */}
                            {isDcConInfoVisible && (
                                <div className="absolute z-[4001] text-left border-t-2 border-custom-blue-hover border-r border-b border-l bg-white left-0 bottom-full mb-2 w-[518px]"> {/* Positioned above button */}
                                    <div className="relative overflow-hidden text-custom-gray-dark leading-normal">
                                        <div className="bg-custom-dropdown-title-bg relative w-full pt-[30px] pb-[27px]">
                                            <span className="absolute top-[14px] left-[18px] text-xs text-custom-gray-dark font-bold">NFT 이벤트</span>
                                            <div className="w-[320px] mx-auto">
                                                {/* Placeholder for Image */}
                                                <div className="bg-gray-300 w-[200px] h-[50px] mx-auto"> (Image Placeholder) </div>
                                            </div>
                                        </div>
                                        <div className="mt-5 mx-[18px]">
                                            <p className="text-xs text-custom-gray-dark font-bold">획득법</p>
                                            <div className="mt-[6px]">
                                                <h4 className="text-custom-blue-hover text-sm font-normal">① NFT 발행</h4>
                                                <p className="ml-[18px] mt-1 text-xs">작성한 게시물을 NFT로 발행하면 <b className="font-bold text-custom-blue-hover">일주일</b> 동안 사용할 수 있습니다. (최초 1회)</p>
                                                <div className="bg-custom-dropdown-bg ml-[18px] rounded-5 p-[6px_8px] mt-[10px] text-xs">
                                                    <b className="text-custom-red-text mr-[6px]">꿀팁!</b>
                                                    <span>발행 후 NFT를 구매할 수 있는 클레이를 받을 수 있어요.<a href="#" className="text-custom-dropdown-link underline ml-1">받으러 가기</a></span>
                                                </div>
                                            </div>
                                            <div className="mt-[14px]">
                                                <h4 className="text-custom-blue-hover text-sm font-normal">② NFT 구매</h4>
                                                <p className="ml-[18px] mt-1 text-xs">다른 이용자의 NFT를 구매하면 <b className="font-bold text-custom-blue-hover">한 달</b> 동안 사용할 수 있습니다. (구매 시마다 갱신)</p>
                                                <div className="bg-custom-dropdown-bg ml-[18px] rounded-5 p-[6px_8px] mt-[10px] text-xs">
                                                    <b className="text-custom-red-text mr-[6px]">꿀팁!</b>
                                                    <span>구매 후 클레이를 한 번 더 받을 수 있어요.<a href="#" className="text-custom-dropdown-link underline ml-1">받으러 가기</a></span>
                                                </div>
                                            </div>
                                        </div>
                                        <div className="mt-[22px] mx-[18px] border-t border-dashed border-custom-border-gray pt-4 mb-6">
                                            <p className="text-xs text-custom-gray-dark font-bold">사용법</p>
                                            <p className="mt-1 text-xs">디시콘에서
                                                <span className="bg-custom-dropdown-link tracking-tighter inline-block px-[8px] h-[23px] leading-tight-23 text-white font-bold rounded-50 shadow-sm mx-1 align-middle">지갑연결</span>
                                                시 바로 사용 가능합니다.
                                            </p>
                                        </div>
                                        <button
                                            type="button"
                                            onClick={toggleDcConInfo}
                                            className="absolute top-0 right-0 p-2 cursor-pointer" // Added padding for easier clicking
                                            aria-label="닫기"
                                        >
                                            <em className="bg-sp-img bg-no-repeat inline-block w-5 h-5 bg-[-195px_-818px]"></em>
                                        </button>
                                    </div>
                                </div>
                            )}
                        </div>

                        {/* Right Buttons (Register) */}
                        <div className="flex">
                            <button
                                type="button" // Should be type="submit" if part of a form
                                className="bg-custom-blue-hover border border-custom-blue-dark text-white font-bold text-xs w-[82px] h-[31px] px-[2px] leading-tight-29 rounded-2 cursor-pointer ml-[3px] shadow-register-button"
                            >
                                등록
                            </button>
                            <button
                                type="button" // Should be type="submit" if part of a form
                                className="bg-custom-blue-register-hover border border-custom-blue-dark text-white font-bold text-xs w-[85px] h-[31px] px-[2px] leading-tight-29 rounded-2 cursor-pointer ml-[3px] shadow-register-recommend-button"
                            >
                                등록+추천
                            </button>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    );
}


export function PostListControls({
    owner = false,
}: {
    owner?: boolean; // Optional prop to determine if the user is the owner
}) {
    // Base button styles - could be abstracted further if needed
    const baseButtonStyles = "w-[82px] h-[35px] border-t border-r border-l border-b-[3px] border-solid border-custom-blue-dark rounded-2 text-sm font-apple-dotum font-bold leading-[31px] pr-[2px] align-middle cursor-pointer";

    return (
        // Main container using flex instead of floats
        <div className="mt-3 pb-5 flex justify-between items-center">

            {/* Left button group */}
            <div className="flex gap-2">
                <button
                    type="button"
                    className={cn(baseButtonStyles, `bg-white text-custom-blue-dark`)}
                >
                    전체글
                </button>
                <button
                    type="button"
                    className={cn(baseButtonStyles, `bg-custom-blue-hover text-white shadow-register-button`)}
                >
                    개념글
                </button>
            </div>

            {/* Right button group */}
            <div className="flex gap-2">
                {owner && (<>
                    <button
                        type="button"
                        // Can potentially link to a posting page, e.g., using React Router's <Link>
                        className={cn(baseButtonStyles, `bg-[#666] text-white border-[#444] shadow-register-button`)}
                    >
                        수정
                    </button>
                    <button
                        type="button"
                        // Can potentially link to a posting page, e.g., using React Router's <Link>
                        className={cn(baseButtonStyles, `bg-[#666] text-white border-[#444] shadow-register-button`)}
                    >
                        삭제
                    </button>
                </>)}
                <button
                    type="button"
                    // Can potentially link to a posting page, e.g., using React Router's <Link>
                    className={cn(baseButtonStyles, `bg-custom-blue-hover text-white shadow-register-button`)}
                >
                    글쓰기
                </button>
            </div>

        </div>
    );
}